@@ -1,5 +1,5 @@
 /*
- * $Id: radstatus.c,v 1.6 1996/03/18 23:20:19 lf Exp $
+ * $Id: radstatus.c,v 1.7 1996/05/05 00:13:21 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -10,17 +10,7 @@
  */
 
 static char	rcsid[] =
-		"$Id: radstatus.c,v 1.6 1996/03/18 23:20:19 lf Exp $";
-
-static char	copyright_1[] =
-		"$Copyright: (C) 1995,1996 Lars Fenneberg $";
-
-static char	copyright_2[] =
-		"$Parts: (C) 1992 Livingston Enterprises, Inc. $";
-
-static char	copyright_3[] =
-		"$Parts: (C) 1992,1993, 1994,1995 The Regents of the \
-University of Michigan and Merit Network, Inc. All Rights Reserved $";
+		"$Id: radstatus.c,v 1.7 1996/05/05 00:13:21 lf Exp $";
 
 #include	<stdio.h>
 #include	<string.h>
@@ -29,16 +19,18 @@ University of Michigan and Merit Network, Inc. All Rights Reserved $";
 #include	<unistd.h>
 #include	<stdlib.h>
 
+#include	"config.h"
 #include	"radius.h"
 #include	"pathnames.h"
+#include	"messages.h"
 
 static char *pname;
 
 void usage(void)
 {
-	fprintf(stderr,"Usage: %s [-Vh] [server]...\n\n", pname);
-        fprintf(stderr,"  -V            output version information\n");
-        fprintf(stderr,"  -h            output this text\n");
+	fprintf(stderr,"Usage: %s [-Vh] [server[:port]]...\n\n", pname);
+	fprintf(stderr,"  -V            output version information\n");
+	fprintf(stderr,"  -h            output this text\n");
 	exit(ERROR_RC);
 }
 
@@ -50,18 +42,21 @@ void version(void)
 
 void main (int argc, char **argv)
 {
-	int             result = ERROR_RC;
-    	int		c,i;
-    	char		*p;
-        
-        extern int optind;
+	int		result = ERROR_RC;
+   	int		c,i;
+    char	*p, msg[4096];
+    SERVER	*srv;
+	
+	extern int optind;
 
 	pname = (pname = strrchr(argv[0],'/'))?pname+1:argv[0];
 
-	if (rc_read_config(_PATH_ETC_RADIUSCLIENT_CONF) != 0)
+	rc_openlog(pname);
+
+	if (rc_read_config(_PATH_RADIUSCLIENT_CONF) != 0)
 		exit(ERROR_RC);
 	
-	if (rc_read_dictionary(conf_dictionary) != 0)
+	if (rc_read_dictionary(rc_conf_str("dictionary")) != 0)
 		exit (ERROR_RC);
 
 	while ((c = getopt(argc,argv,"hV")) > 0)
@@ -85,26 +80,35 @@ void main (int argc, char **argv)
 	if (argc > 0) {
 		for (i = 0; i < argc; i++) {
 			if ((p = strchr(argv[i], ':')) == NULL) {
-				result = rc_check(argv[i],rc_getport(AUTH));
+				result = rc_check(argv[i],rc_getport(AUTH), msg);
 			} else if (!strcmp(p+1, "auth")) {
 				*p = '\0';
-				result = rc_check(argv[i],rc_getport(AUTH));
+				result = rc_check(argv[i],rc_getport(AUTH), msg);
 			} else if (!strcmp(p+1, "acct")) {
 				*p = '\0';
-				result = rc_check(argv[i],rc_getport(ACCT));
+				result = rc_check(argv[i],rc_getport(ACCT), msg);
 			} else {
 				*p = '\0';
-				result = rc_check(argv[i], atoi(p+1));
+				result = rc_check(argv[i], atoi(p+1), msg);
 			}
+			if (result == OK_RC)
+				printf(msg);
+			else
+				printf(SC_STATUS_FAILED);
 		}
 	} else {
-		for(i=0; i<conf_numauth ; i++)
+		srv = rc_conf_srv("authserver");
+		for(i=0; i<srv->max ; i++)
 		{
-			result = rc_check(conf_authserver[i],conf_authserver_port[i]);
+			result = rc_check(srv->name[i], srv->port[i], msg);
+			printf(msg);
 		}
-		for(i=0; i<conf_numacct ; i++)
+		
+		srv = rc_conf_srv("acctserver");
+		for(i=0; i<srv->max ; i++)
 		{
-			result = rc_check(conf_authserver[i],conf_authserver_port[i]);
+			result = rc_check(srv->name[i], srv->port[i], msg);
+			printf(msg);
 		}
 	}
 }
